
# q-expansion of newform 1014.4.b.q, downloaded from the LMFDB on 22 May 2024.

# We generate the q-expansion using the Hecke eigenvalues a_p at the primes.
# Each a_p is given as a linear combination
# of the following basis for the coefficient ring.

def make_data():

    from sage.all import prod, floor, prime_powers, gcd, QQ, primes_first_n, next_prime, RR

    def discrete_log(elts, gens, mod):
        # algorithm 2.2, page 16 of https://arxiv.org/abs/0903.2785
        def table_gens(gens, mod):
            T = [1]
            n = len(gens)
            r = [None]*n
            s = [None]*n
            for i in range(n):
                beta = gens[i]
                r[i] = 1
                N = len(T)
                while beta not in T:
                    for Tj in T[:N]:
                        T.append((beta*Tj) % mod)
                    beta = (beta*gens[i]) % mod
                    r[i] += 1
                s[i] = T.index(beta)
            return T, r, s
        T, r, s = table_gens(gens, mod)
        n = len(gens)
        N = [ prod(r[:j]) for j in range(n) ]
        Z = lambda s: [ (floor(s/N[j]) % r[j]) for j in range(n)]
        return [Z(T.index(elt % mod)) for elt in elts]
    def extend_multiplicatively(an):
        for pp in prime_powers(len(an)-1):
            for k in range(1, (len(an) - 1)//pp + 1):
                if gcd(k, pp) == 1:
                    an[pp*k] = an[pp]*an[k]
    from sage.all import PolynomialRing, NumberField, ZZ
    R = PolynomialRing(QQ, "x")
    f = R(poly_data)
    K = NumberField(f, "a")
    betas = [K([c/ZZ(den) for c in num]) for num, den in basis_data]
    convert_elt_to_field = lambda elt: sum(c*beta for c, beta in zip(elt, betas))
    # convert aps to K elements
    primes = primes_first_n(len(aps_data))
    good_primes = [p for p in primes if not p.divides(level)]
    aps = map(convert_elt_to_field, aps_data)
    if not hecke_ring_character_values:
        # trivial character
        char_values = dict(zip(good_primes, [1]*len(good_primes)))
    else:
        gens = [elt[0] for elt in hecke_ring_character_values]
        gens_values = [convert_elt_to_field(elt[1]) for elt in hecke_ring_character_values]
        char_values = dict([(
            p,prod(g**k for g, k in zip(gens_values, elt)))
            for p, elt in zip(good_primes, discrete_log(good_primes, gens, level))
            ])
    an_list_bound = next_prime(primes[-1])
    an = [0]*an_list_bound
    an[1] = 1
    
    from sage.all import PowerSeriesRing
    PS = PowerSeriesRing(K, "q")
    for p, ap in zip(primes, aps):
        if p.divides(level):
            euler_factor = [1, -ap]
        else:
            euler_factor = [1, -ap, p**(weight - 1) * char_values[p]]
        k = RR(an_list_bound).log(p).floor() + 1
        foo = (1/PS(euler_factor)).padded_list(k)
        for i in range(1, k):
            an[p**i] = foo[i]
    extend_multiplicatively(an)
    return PS(an)
level = 1014
weight = 4
poly_data = [4178851762176, 0, 224458698240, 0, 4731667920, 0, 50362537, 0, 287958, 0, 845, 0, 1]

# The entries in the following list give a basis for the
# coefficient ring in terms of a root of the defining polynomial above.
# Each line consists of the coefficients of the numerator, and a denominator.
basis_data  = [[[1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], 1], [[761522374634112000, 0, 85030867316336256, 0, 2465873069840339, 0, 28618044849186, 0, 142769968975, 0, 254679227, 0], 4287070271667456], [[-480589958874816161280, 0, -22977155008391522400, 0, -408221819281128059, 0, -3372445451921010, 0, -13104030855607, 0, -19352151011, 0], 4287070271667456], [[0, -11119687594622208, 0, -530883139359744, 0, -9426147340375, 0, -77891726586, 0, -302892707, 0, -447775], 10261971772416], [[54097133077859913216, 0, 2583923715751807296, 0, 45876715538632829, 0, 378924665061246, 0, 1472552490625, 0, 2175408533, 0], 329774636282112], [[53575911706845999744, 0, 2559322432915567011, 0, 45463344240996040, 0, 375794682802131, 0, 1461602528585, 0, 2160967510, 0], 267941891979216], [[0, -1173004258631662114560, 0, -55751085971677549872, 0, -982787815234718719, 0, -8039661002027418, 0, -30899064670331, 0, -45124973671], 668782962380123136], [[-12162116311209176256, 0, -580923363040093962, 0, -10315836550396565, 0, -85220941965720, 0, -331233973639, 0, -489398321, 0], 41221829535264], [[0, -687916519338587753088, 0, -32924998905266560068, 0, -585611893534000189, 0, -4844575296165954, 0, -18852044969069, 0, -27881483581], 167195740595030784], [[0, 2870841801490769844864, 0, 136976856602439345048, 0, 2430363565004726339, 0, 20060765977082586, 0, 77904138878215, 0, 115005844379], 334391481190061568], [[0, 73960467683972333184, 0, 3527884490561180616, 0, 62543958643238953, 0, 515830116892878, 0, 2001783658997, 0, 2953462321], 8574140543334912], [[0, -253019246309397451296, 0, -12127777597202873286, 0, -216104469651546701, 0, -1791248266123428, 0, -6984074142643, 0, -10348550369], 27865956765838464]]

hecke_ring_character_values = [[677, [1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0]], [847, [-1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0]]]
aps_data = [[0, 0, 0, -2, 0, 0, 0, 0, 0, 0, 0, 0], [3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, -1, 1, -1, 0], [0, 0, 0, 10, 0, 0, 0, 0, 0, 2, -1, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [-5, 2, 4, 0, 3, -1, 0, 2, 0, 0, 0, 0], [0, 0, 0, -36, 0, 0, 0, 0, -1, 2, 2, -1], [-41, -3, -9, 0, -2, 0, 0, -1, 0, 0, 0, 0], [59, -10, 4, 0, 1, -3, 0, 3, 0, 0, 0, 0], [0, 0, 0, -50, 0, 0, -1, 0, 9, -4, -14, 5], [0, 0, 0, 90, 0, 0, 3, 0, -8, -10, -1, 10], [0, 0, 0, 51, 0, 0, -5, 0, -5, 13, 7, 3], [-79, 9, 0, 0, 23, 17, 0, 11, 0, 0, 0, 0], [0, 0, 0, -102, 0, 0, -14, 0, -1, -20, -8, 7], [382, 2, 8, 0, -11, -4, 0, -8, 0, 0, 0, 0], [0, 0, 0, -37, 0, 0, 5, 0, 3, 28, 34, -14], [59, -10, -14, 0, 39, 23, 0, 14, 0, 0, 0, 0], [0, 0, 0, -105, 0, 0, 10, 0, -31, -13, -24, 43], [0, 0, 0, 225, 0, 0, -32, 0, -10, -17, -14, -6], [0, 0, 0, -162, 0, 0, -48, 0, 15, -8, 18, -8], [526, -16, 5, 0, -9, -22, 0, -1, 0, 0, 0, 0], [0, 0, 0, -77, 0, 0, 16, 0, -35, 22, 47, -54], [0, 0, 0, -253, 0, 0, -16, 0, 47, 31, 4, -21], [0, 0, 0, 227, 0, 0, -68, 0, -12, 5, 50, -41], [151, -5, 75, 0, -14, -45, 0, -44, 0, 0, 0, 0], [182, 15, -13, 0, 24, -57, 0, -25, 0, 0, 0, 0], [620, 7, 15, 0, -7, -68, 0, -52, 0, 0, 0, 0], [0, 0, 0, -411, 0, 0, 1, 0, 5, 15, -13, -43], [652, 77, -30, 0, 62, -36, 0, 41, 0, 0, 0, 0], [597, 26, -83, 0, -3, -50, 0, 84, 0, 0, 0, 0], [319, -39, -48, 0, -4, 29, 0, 17, 0, 0, 0, 0], [0, 0, 0, 34, 0, 0, 11, 0, -37, -14, -25, -23], [-656, -11, 25, 0, 83, 35, 0, 113, 0, 0, 0, 0], [0, 0, 0, 1030, 0, 0, -51, 0, -12, 0, -64, -6], [0, 0, 0, -1094, 0, 0, 20, 0, -55, 6, -75, 111], [17, 119, 32, 0, 105, 107, 0, 21, 0, 0, 0, 0], [0, 0, 0, -531, 0, 0, 142, 0, 7, 73, -8, 15], [0, 0, 0, -630, 0, 0, -117, 0, 7, -78, -25, -41], [-837, -8, -36, 0, 13, 1, 0, 109, 0, 0, 0, 0], [-709, -82, -134, 0, -100, 29, 0, -50, 0, 0, 0, 0], [-832, -76, 63, 0, 23, 125, 0, -72, 0, 0, 0, 0], [488, -180, -21, 0, -101, 25, 0, -34, 0, 0, 0, 0], [0, 0, 0, 762, 0, 0, -135, 0, 141, -60, -127, 11], [0, 0, 0, 1033, 0, 0, -50, 0, 77, -28, -37, -6], [608, 130, -44, 0, 24, -256, 0, -33, 0, 0, 0, 0], [671, -116, -35, 0, -172, 124, 0, -96, 0, 0, 0, 0], [0, 0, 0, 1979, 0, 0, 19, 0, -65, 73, -3, 31], [0, 0, 0, 997, 0, 0, -70, 0, -84, 27, -38, -117], [0, 0, 0, -651, 0, 0, -22, 0, 114, -157, 18, 42], [-2779, 156, 78, 0, 103, 1, 0, -40, 0, 0, 0, 0], [0, 0, 0, 810, 0, 0, 3, 0, -174, 210, 9, -14], [0, 0, 0, -298, 0, 0, 123, 0, 132, -44, -15, -27], [-1887, -150, 12, 0, -121, 188, 0, -5, 0, 0, 0, 0], [-662, 2, 131, 0, 125, 187, 0, -152, 0, 0, 0, 0], [2752, 182, 107, 0, 199, 59, 0, 60, 0, 0, 0, 0], [1927, 225, 69, 0, 47, -6, 0, -63, 0, 0, 0, 0], [0, 0, 0, 689, 0, 0, -32, 0, 21, 251, 8, -98], [726, 21, -39, 0, 25, 201, 0, -131, 0, 0, 0, 0], [0, 0, 0, -1153, 0, 0, 1, 0, 48, 151, 41, -46], [1201, -226, -52, 0, 29, -49, 0, 228, 0, 0, 0, 0], [0, 0, 0, 258, 0, 0, -210, 0, 167, -192, -127, -305], [0, 0, 0, 2455, 0, 0, -76, 0, 238, 65, -80, 62], [-1898, 100, 271, 0, 183, -43, 0, 68, 0, 0, 0, 0], [-2525, -303, 41, 0, -325, -156, 0, -349, 0, 0, 0, 0], [0, 0, 0, 802, 0, 0, 279, 0, 32, -21, 2, 209], [0, 0, 0, 271, 0, 0, 53, 0, -187, -25, 169, -183], [429, 8, -198, 0, -211, 315, 0, 207, 0, 0, 0, 0], [-1274, -337, 126, 0, -168, -35, 0, -114, 0, 0, 0, 0], [0, 0, 0, 626, 0, 0, 396, 0, 88, 30, 320, 314], [0, 0, 0, 299, 0, 0, -32, 0, 113, -61, -466, -7], [0, 0, 0, 3423, 0, 0, 214, 0, 73, 205, -250, 189], [-4930, -126, 135, 0, -167, 272, 0, 37, 0, 0, 0, 0], [-2938, -311, -537, 0, -149, 91, 0, 275, 0, 0, 0, 0], [0, 0, 0, 2290, 0, 0, 191, 0, -204, 440, -203, 298], [0, 0, 0, -4221, 0, 0, 16, 0, -1, 33, -408, 307], [-1527, -329, -335, 0, 202, 120, 0, 464, 0, 0, 0, 0], [0, 0, 0, -168, 0, 0, 356, 0, -235, 76, -104, 631], [0, 0, 0, -103, 0, 0, 354, 0, -2, -457, -254, 546], [0, 0, 0, 796, 0, 0, 168, 0, -401, 199, -697, 390], [3899, -89, -345, 0, -262, -416, 0, 350, 0, 0, 0, 0], [0, 0, 0, -1226, 0, 0, 422, 0, -311, 306, 62, 263], [0, 0, 0, -1515, 0, 0, 72, 0, 51, -279, 452, -497], [7381, -154, 53, 0, -218, 116, 0, 209, 0, 0, 0, 0], [2379, -368, 313, 0, 118, 37, 0, 175, 0, 0, 0, 0], [-1639, 162, 521, 0, 574, 194, 0, 129, 0, 0, 0, 0], [0, 0, 0, 2864, 0, 0, -266, 0, -231, 150, 440, -163], [0, 0, 0, 2592, 0, 0, 464, 0, -111, -64, -33, 915], [0, 0, 0, -5453, 0, 0, -222, 0, 140, 550, 115, 71], [0, 0, 0, -2696, 0, 0, 332, 0, -720, 336, -80, 464], [2907, 348, -117, 0, 301, 488, 0, 484, 0, 0, 0, 0], [0, 0, 0, -488, 0, 0, -259, 0, 620, -206, 189, -118], [0, 0, 0, 277, 0, 0, 356, 0, -166, 5, 202, 407], [-1124, 715, 142, 0, 218, 42, 0, -2, 0, 0, 0, 0], [0, 0, 0, 3924, 0, 0, -62, 0, 436, -212, -562, 568], [-3349, 1023, 41, 0, -22, -698, 0, -221, 0, 0, 0, 0], [0, 0, 0, 1060, 0, 0, 40, 0, -536, 386, 96, -548], [593, -405, -538, 0, -841, 31, 0, -183, 0, 0, 0, 0], [-8839, 25, -357, 0, -138, 454, 0, 481, 0, 0, 0, 0], [0, 0, 0, -5077, 0, 0, -323, 0, -107, 165, -171, 305], [-2794, -267, -62, 0, -636, -598, 0, -347, 0, 0, 0, 0], [0, 0, 0, -1723, 0, 0, 190, 0, 22, 1329, 512, -712], [-10080, -118, -179, 0, -386, 195, 0, 24, 0, 0, 0, 0], [1310, -101, 665, 0, -95, -713, 0, -357, 0, 0, 0, 0], [5477, 529, 147, 0, -346, 614, 0, -481, 0, 0, 0, 0], [0, 0, 0, 663, 0, 0, 316, 0, -411, 436, 1221, -430], [0, 0, 0, -6535, 0, 0, -669, 0, 453, -49, 176, -947], [0, 0, 0, 4840, 0, 0, -74, 0, 470, 74, -574, 94], [5534, -334, -43, 0, 711, 465, 0, 32, 0, 0, 0, 0], [-5021, 567, 921, 0, 1036, -856, 0, 94, 0, 0, 0, 0], [-8855, 454, -231, 0, 16, 5, 0, 403, 0, 0, 0, 0], [0, 0, 0, 8992, 0, 0, -319, 0, 548, -602, -511, 506], [0, 0, 0, -4430, 0, 0, 604, 0, -120, 264, -902, 254], [0, 0, 0, 1376, 0, 0, -16, 0, 1513, -102, 354, -373], [0, 0, 0, -2287, 0, 0, 78, 0, -19, -38, 325, -182], [-8023, -825, 163, 0, -428, -10, 0, -619, 0, 0, 0, 0], [0, 0, 0, -300, 0, 0, 566, 0, 79, 1314, 422, -467], [2212, -659, -339, 0, -347, -305, 0, 535, 0, 0, 0, 0], [2282, 90, 39, 0, 479, 1720, 0, 621, 0, 0, 0, 0], [-2582, -423, 699, 0, 163, -18, 0, 294, 0, 0, 0, 0], [0, 0, 0, 2573, 0, 0, 84, 0, 123, -697, -14, -703], [3038, -11, 117, 0, -337, 1084, 0, -366, 0, 0, 0, 0], [7746, -119, 352, 0, 298, 629, 0, -480, 0, 0, 0, 0], [0, 0, 0, 5690, 0, 0, 306, 0, -307, -36, -770, 650], [0, 0, 0, -3125, 0, 0, -57, 0, -365, -197, -695, -165], [1074, 175, 173, 0, -137, -867, 0, -605, 0, 0, 0, 0], [0, 0, 0, -10405, 0, 0, -1040, 0, 1164, 239, 644, -906], [-10548, 866, -364, 0, 150, -66, 0, -578, 0, 0, 0, 0], [7006, -401, 814, 0, -446, -147, 0, -716, 0, 0, 0, 0], [0, 0, 0, 1833, 0, 0, 222, 0, -121, -1255, -580, 263], [0, 0, 0, 2362, 0, 0, 157, 0, 370, -836, -235, 276], [0, 0, 0, -9728, 0, 0, -710, 0, -241, -634, -34, -601], [-8405, -445, -1158, 0, 167, 459, 0, 1328, 0, 0, 0, 0], [-8824, 217, -567, 0, -125, 149, 0, -971, 0, 0, 0, 0], [0, 0, 0, -2321, 0, 0, 784, 0, -447, 539, 208, -901], [0, 0, 0, 1838, 0, 0, -354, 0, 1152, 1356, 166, -552], [0, 0, 0, 1146, 0, 0, -522, 0, 1079, 947, 973, -1486], [0, 0, 0, -7293, 0, 0, 1023, 0, -1733, 937, -161, 1059], [-7940, 678, -277, 0, 61, -1657, 0, 13, 0, 0, 0, 0], [5327, 337, -494, 0, -769, -1113, 0, -811, 0, 0, 0, 0], [0, 0, 0, -6850, 0, 0, -1184, 0, 1055, -340, -362, -1529], [0, 0, 0, -7946, 0, 0, -100, 0, 250, -536, -486, 291], [-6909, 695, 1123, 0, 1420, -559, 0, -126, 0, 0, 0, 0], [0, 0, 0, 18112, 0, 0, -237, 0, -207, 652, -380, -257], [-15347, -201, -887, 0, -1022, -868, 0, -647, 0, 0, 0, 0], [0, 0, 0, 6808, 0, 0, 791, 0, -1221, 22, 173, 681], [0, 0, 0, -8133, 0, 0, -173, 0, 1570, -1069, -311, -1062], [-8980, 974, 1246, 0, 478, -556, 0, -808, 0, 0, 0, 0], [13115, 713, 1025, 0, 1856, 1150, 0, 1233, 0, 0, 0, 0], [0, 0, 0, -21964, 0, 0, 126, 0, 261, 1210, 798, -83], [0, 0, 0, 18252, 0, 0, 531, 0, -125, -1468, 153, 233], [9993, -1670, -324, 0, -2775, -1415, 0, -1274, 0, 0, 0, 0], [6877, 180, -224, 0, 313, -1019, 0, 324, 0, 0, 0, 0], [8481, 968, -227, 0, -734, 92, 0, 260, 0, 0, 0, 0], [-14916, -387, 1321, 0, -939, -1209, 0, 101, 0, 0, 0, 0], [13505, 32, -723, 0, -56, -1348, 0, 108, 0, 0, 0, 0], [20800, -142, -1460, 0, 1003, 594, 0, 610, 0, 0, 0, 0], [0, 0, 0, 4068, 0, 0, -945, 0, -725, -174, 685, -715], [4282, -1608, -232, 0, -1142, 814, 0, 817, 0, 0, 0, 0], [0, 0, 0, 412, 0, 0, -14, 0, -196, 480, -233, -1612], [0, 0, 0, 27516, 0, 0, -676, 0, 342, 28, 98, -857], [-4954, -1788, -835, 0, -1443, 651, 0, 560, 0, 0, 0, 0], [0, 0, 0, -14141, 0, 0, 126, 0, -253, -931, -1407, 751], [-10413, -607, -253, 0, -278, -340, 0, -1110, 0, 0, 0, 0], [0, 0, 0, 3966, 0, 0, 3, 0, 952, 592, -301, 200], [0, 0, 0, 11327, 0, 0, -394, 0, 531, -941, -728, 867], [12338, 700, -1228, 0, 355, -560, 0, 432, 0, 0, 0, 0], [13330, 1244, 1035, 0, -55, 2083, 0, 32, 0, 0, 0, 0], [0, 0, 0, 645, 0, 0, 729, 0, 811, -627, 634, -915], [-13456, -915, 1160, 0, 162, 160, 0, -1427, 0, 0, 0, 0], [0, 0, 0, -18588, 0, 0, -622, 0, -389, -1702, 520, -1125], [0, 0, 0, -1657, 0, 0, -1258, 0, 724, 61, -1014, -864], [3940, -975, -715, 0, -739, -261, 0, 735, 0, 0, 0, 0], [0, 0, 0, 538, 0, 0, -413, 0, 400, -1010, 193, -810], [-3564, 275, -148, 0, 488, -826, 0, 1227, 0, 0, 0, 0], [12635, 1057, 2986, 0, 655, -639, 0, -1205, 0, 0, 0, 0], [0, 0, 0, 16965, 0, 0, -305, 0, 638, 383, -2069, 412], [0, 0, 0, -3120, 0, 0, -1235, 0, 789, -1537, 1166, -754], [-10954, -967, 514, 0, 188, -482, 0, -1695, 0, 0, 0, 0], [-3837, 1443, -1449, 0, 1464, 2122, 0, -175, 0, 0, 0, 0], [0, 0, 0, 13985, 0, 0, 626, 0, -120, -1723, -784, 1373], [8576, 504, -247, 0, 831, 901, 0, -1037, 0, 0, 0, 0], [-14254, 3435, 169, 0, 2331, 531, 0, 261, 0, 0, 0, 0], [0, 0, 0, 1413, 0, 0, 2169, 0, -112, 1103, -583, -266], [0, 0, 0, 23502, 0, 0, 180, 0, 869, -186, 800, 345], [5988, 334, 27, 0, 577, 380, 0, -325, 0, 0, 0, 0], [-17625, -744, -442, 0, 577, 469, 0, 2092, 0, 0, 0, 0], [0, 0, 0, -8435, 0, 0, -1238, 0, 509, -1109, -170, -1027], [0, 0, 0, -14201, 0, 0, 393, 0, 2150, -714, -2500, 703], [0, 0, 0, -6686, 0, 0, 1149, 0, -500, 1514, 459, 336], [8709, 406, -912, 0, -97, -123, 0, -1529, 0, 0, 0, 0], [0, 0, 0, -22037, 0, 0, -234, 0, 1256, 1338, -1639, -1189], [27267, 944, 578, 0, 1705, 1189, 0, 1944, 0, 0, 0, 0], [0, 0, 0, -5001, 0, 0, 434, 0, 1341, -1495, -588, -1992], [5756, 1803, 2733, 0, 648, -403, 0, -1687, 0, 0, 0, 0], [32583, 236, 1595, 0, -2350, -3820, 0, -2978, 0, 0, 0, 0], [0, 0, 0, 24722, 0, 0, -356, 0, 2035, -826, -1205, 1553], [-12600, 380, -404, 0, -138, -1244, 0, 492, 0, 0, 0, 0], [0, 0, 0, -14870, 0, 0, -2305, 0, 1089, 1072, 2353, -3031], [-19857, 1369, -253, 0, -800, 890, 0, -2107, 0, 0, 0, 0], [0, 0, 0, -38434, 0, 0, -1523, 0, -1284, -674, -1985, 286], [7006, -15, 2157, 0, 181, -1717, 0, -1594, 0, 0, 0, 0], [0, 0, 0, 21573, 0, 0, -1525, 0, 1870, -1627, 171, -2354], [-12239, 476, -358, 0, 1652, -33, 0, 2286, 0, 0, 0, 0], [0, 0, 0, -13741, 0, 0, 2628, 0, -2345, 1248, 2145, 338], [-7756, -734, 662, 0, -1318, -3252, 0, -695, 0, 0, 0, 0], [0, 0, 0, 9506, 0, 0, -1078, 0, -1827, 914, -116, 1310], [-7626, 1697, 149, 0, -431, 1078, 0, -1204, 0, 0, 0, 0], [0, 0, 0, 18629, 0, 0, -1279, 0, -1461, -367, 2225, -647], [-12185, 169, -864, 0, -2597, -2153, 0, -3235, 0, 0, 0, 0], [-7561, -680, 911, 0, 255, 1604, 0, -1246, 0, 0, 0, 0], [-21771, -139, 850, 0, -3187, 463, 0, -1216, 0, 0, 0, 0], [2006, -403, -1941, 0, -837, 1905, 0, 2005, 0, 0, 0, 0], [0, 0, 0, -2822, 0, 0, 1569, 0, 1822, -352, 47, 1916], [0, 0, 0, 4067, 0, 0, 321, 0, 160, 211, 1619, 174], [0, 0, 0, -1817, 0, 0, 827, 0, -389, 626, 210, 2186], [7435, -304, -2529, 0, 2090, 560, 0, -357, 0, 0, 0, 0], [-13618, 1928, 698, 0, -1352, -1948, 0, -924, 0, 0, 0, 0], [0, 0, 0, 29175, 0, 0, 948, 0, -2449, 1293, -2784, 967], [0, 0, 0, -13989, 0, 0, 541, 0, 3599, 39, -567, -1844], [46536, 816, -2982, 0, 2184, -300, 0, 1240, 0, 0, 0, 0], [0, 0, 0, -17424, 0, 0, 3683, 0, -1375, 358, 1659, 1816], [0, 0, 0, 47089, 0, 0, 1466, 0, -503, -2277, 1952, 2303], [0, 0, 0, -26190, 0, 0, 112, 0, -1206, -852, -915, 2764], [23648, 70, 1187, 0, -1411, -3095, 0, 86, 0, 0, 0, 0], [18312, 1602, 1779, 0, -839, -2285, 0, -576, 0, 0, 0, 0], [4580, 659, -2326, 0, -1340, -3498, 0, 579, 0, 0, 0, 0], [-10212, -1942, -1557, 0, -2609, 2825, 0, 614, 0, 0, 0, 0], [-20762, -1339, -1010, 0, -3507, 2136, 0, -1311, 0, 0, 0, 0], [0, 0, 0, -1969, 0, 0, 816, 0, -242, 489, -228, 3637], [26001, -1133, 821, 0, 530, -2154, 0, -1333, 0, 0, 0, 0], [3713, 4421, 1129, 0, 1208, 712, 0, 115, 0, 0, 0, 0], [0, 0, 0, 8877, 0, 0, 1633, 0, -1932, 906, 20, -2845], [-7120, 1403, 866, 0, -1732, -636, 0, -1245, 0, 0, 0, 0], [-6507, -3545, -235, 0, -296, 790, 0, -939, 0, 0, 0, 0], [0, 0, 0, -3009, 0, 0, 2679, 0, -41, -437, 365, 2577], [0, 0, 0, -37571, 0, 0, -3284, 0, 1293, -368, 2015, -3272], [0, 0, 0, -27635, 0, 0, 3273, 0, 1617, -146, 600, 2596], [9979, -2604, -311, 0, -1048, -1634, 0, 626, 0, 0, 0, 0], [-1423, 82, -513, 0, 540, 610, 0, 2814, 0, 0, 0, 0], [0, 0, 0, -5084, 0, 0, -4308, 0, 766, 1144, -445, -1742], [3670, -539, -58, 0, 2712, -1256, 0, 1057, 0, 0, 0, 0], [-46183, -1715, 1534, 0, -1987, -575, 0, -769, 0, 0, 0, 0], [0, 0, 0, 7355, 0, 0, 3545, 0, -4267, -55, -2449, 4453], [0, 0, 0, 301, 0, 0, 3231, 0, 163, 779, 2601, 67], [3440, -646, 3033, 0, 1691, -2549, 0, 408, 0, 0, 0, 0], [0, 0, 0, 26438, 0, 0, 3057, 0, -1069, -308, -3392, 3387], [0, 0, 0, 30588, 0, 0, -655, 0, -1167, 3980, 2510, -2205], [0, 0, 0, 15574, 0, 0, 684, 0, -2609, 1362, -880, 1047], [35433, -2451, 1556, 0, 939, 3179, 0, -1563, 0, 0, 0, 0], [0, 0, 0, -39120, 0, 0, -880, 0, -2339, -2092, -2024, 2969], [0, 0, 0, 22368, 0, 0, 2015, 0, -3175, 1500, -3003, 621], [0, 0, 0, 23158, 0, 0, 2122, 0, 635, 1114, 1676, 733], [8550, -3867, -724, 0, -2668, 1637, 0, -2706, 0, 0, 0, 0], [-13348, -824, -810, 0, -726, 333, 0, -1395, 0, 0, 0, 0], [0, 0, 0, -5929, 0, 0, -1058, 0, 838, -340, -1033, 3295], [27386, 903, -706, 0, 1392, 996, 0, 155, 0, 0, 0, 0], [0, 0, 0, -38720, 0, 0, 2578, 0, -919, 2214, 2754, -1023], [11891, 31, 2946, 0, -1369, 1572, 0, 1888, 0, 0, 0, 0], [0, 0, 0, -22859, 0, 0, -1834, 0, 269, 147, -3239, 2361], [20006, 1989, -5757, 0, 1379, 2789, 0, 1488, 0, 0, 0, 0], [11563, 2194, -2005, 0, -1321, 3276, 0, -2286, 0, 0, 0, 0], [0, 0, 0, 54919, 0, 0, -320, 0, 600, -1791, -1440, -192], [-8646, -1334, -1413, 0, -1555, -5099, 0, 426, 0, 0, 0, 0], [0, 0, 0, -10830, 0, 0, 2834, 0, -3013, 562, 506, 889], [8820, 1751, -3155, 0, -733, -4359, 0, -853, 0, 0, 0, 0], [0, 0, 0, 47416, 0, 0, -1009, 0, 1091, -2834, 217, 1492], [0, 0, 0, 22144, 0, 0, 1213, 0, 4392, 376, -49, -4174], [0, 0, 0, 20738, 0, 0, -768, 0, 1401, -752, 3638, -4217], [16326, 4066, 2138, 0, 3915, 82, 0, 1120, 0, 0, 0, 0], [-20060, 1709, 2287, 0, 981, -2397, 0, -211, 0, 0, 0, 0], [0, 0, 0, 1778, 0, 0, -817, 0, 4583, 1110, 833, -4543], [0, 0, 0, -6671, 0, 0, -1424, 0, 1542, -121, -4258, -1631], [-6284, -1296, 2170, 0, -199, 4404, 0, -28, 0, 0, 0, 0], [-40574, 255, 2841, 0, 2127, 3502, 0, 778, 0, 0, 0, 0], [0, 0, 0, -5793, 0, 0, -3153, 0, 1895, 3999, 2644, -4071], [0, 0, 0, -31456, 0, 0, -53, 0, 2572, 2558, 2031, 787], [0, 0, 0, -43201, 0, 0, 227, 0, -2005, -205, 3533, -2233], [0, 0, 0, 11032, 0, 0, 689, 0, -3238, 3573, 2218, -3435], [-19242, 2687, -248, 0, 3202, -2191, 0, 1372, 0, 0, 0, 0], [16955, 718, 379, 0, 1266, 2202, 0, 150, 0, 0, 0, 0], [0, 0, 0, -16466, 0, 0, -3795, 0, 1373, -2288, 1937, -2870], [51336, 941, -1502, 0, 4250, 2148, 0, 1237, 0, 0, 0, 0], [0, 0, 0, -461, 0, 0, -41, 0, 809, 2987, 1853, 1001], [0, 0, 0, 11172, 0, 0, -226, 0, 2556, -2378, -350, 1584], [-43804, -2142, 1240, 0, -200, 964, 0, 622, 0, 0, 0, 0], [12208, 4798, 1631, 0, -1342, -227, 0, -4654, 0, 0, 0, 0], [0, 0, 0, -34093, 0, 0, -3042, 0, -637, 1041, 284, -4652], [0, 0, 0, -8449, 0, 0, 1638, 0, 2856, -1749, -3023, 1480], [35032, 784, -3723, 0, -2025, -2489, 0, -1626, 0, 0, 0, 0], [41496, 2453, 7109, 0, 2103, -3062, 0, -3480, 0, 0, 0, 0], [30993, -1754, 564, 0, -2609, -1089, 0, 1855, 0, 0, 0, 0], [0, 0, 0, -13829, 0, 0, -2656, 0, 356, 187, 3424, -2284], [0, 0, 0, 28211, 0, 0, 921, 0, -1303, -4963, -247, 2180], [2850, 1157, 216, 0, 4428, -616, 0, 4749, 0, 0, 0, 0], [-6501, 1856, -3280, 0, -747, 54, 0, 4259, 0, 0, 0, 0], [27505, 2920, 1658, 0, 1942, -1463, 0, -246, 0, 0, 0, 0], [-29332, -1271, 5697, 0, -949, -2634, 0, -1296, 0, 0, 0, 0], [-6457, -432, -2173, 0, 4606, 1146, 0, 1403, 0, 0, 0, 0], [0, 0, 0, 16599, 0, 0, -1490, 0, 248, -3199, 58, -1592], [-13741, -6053, -1656, 0, -3295, -719, 0, 266, 0, 0, 0, 0], [0, 0, 0, 2076, 0, 0, 25, 0, -2437, 626, 3543, -722], [-17932, 7859, 2689, 0, 4241, 324, 0, -220, 0, 0, 0, 0]]
